<?php
	session_start();
	include("conex.php");
	// Verifica si las variables de sesión están definidas
	if (!isset($_SESSION['idusuario'], $_SESSION['usuario'], $_SESSION['sucursal'])) {
		header('Location: index.php'); // Redirige al login si no hay sesión activa
		exit();
	}

	$idusuario = htmlspecialchars($_SESSION['idusuario']);
	$usuario = htmlspecialchars($_SESSION['usuario']);
	$sucursal_id = $_SESSION['sucursal'] ?? null;

	if (!is_numeric($sucursal_id)) {
		die("ID de sucursal inválido");
	}

	// Verifica que la conexión esté establecida
	if (!isset($conn) || $conn === null) {
		die("Error: No se pudo establecer la conexión a la base de datos.");
	}

	// Consulta preparada
	$query = "SELECT sucursal FROM tbr_sucursal WHERE idsucursal = ?";
	$stmt = mysqli_prepare($conn, $query);

	if ($stmt) {
		mysqli_stmt_bind_param($stmt, "i", $sucursal_id);
		mysqli_stmt_execute($stmt);
		$result = mysqli_stmt_get_result($stmt);
		
		if ($row = mysqli_fetch_assoc($result)) {
			$sucursal = $row['sucursal'];
		} else {
			die("Sucursal no encontrada.");
		}
		
		mysqli_stmt_close($stmt);
	} else {
		die("Error en la preparación de la consulta.");
	}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Panel de administración para gestionar usuarios y configuraciones.">
    <meta name="keywords" content="panel, administración, usuarios, reportes, gestión">
    <title>Sistema de Gestión</title>
    <link rel="shortcut icon" href="../resources/img/crud.ico">
    <!-- Carga de bibliotecas necesarias -->
    
	<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/dayjs/1.11.7/dayjs.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/dayjs/1.11.7/locale/es.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta2/dist/css/bootstrap-select.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-lite.min.css">
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    <link href="https://cdn.jsdelivr.net/npm/sweetalert2@11/dist/sweetalert2.min.css" rel="stylesheet">
	
    <style>
         /* Aplicar un tamaño de fuente y altura mínima global para el formulario */
		.form-control, .selectpicker, .btn {
			font-size: 2em;
			min-height: 2em;
		}
        body {
            background-color: #f4f6f9;
        }
        .navbar {
            margin-bottom: 20px;
        }
        .content {
            padding: 1rem;
        }
        .sidebar {
			width: 250px;
			background: #343a40;
			padding: 20px;
			height: 100vh;
			position: fixed;
			left: 0;
			top: 0;
			display: flex;
			flex-direction: column;
			align-items: center;
		}

		.sidebar h4 {
			font-size: 1.2rem;
		}

		.sidebar a {
			color: white;
			text-decoration: none;
			padding: 15px;
			width: 100%;
			display: flex;
			flex-direction: column;
			align-items: center;
			transition: background 0.3s, transform 0.2s;
		}

		.sidebar a i {
			margin-bottom: 8px;
		}

		.sidebar a:hover {
			background: rgba(255, 255, 255, 0.1);
			transform: scale(1.05);
			border-radius: 8px;
		}

		.sidebar .active {
			font-weight: bold;
			color: #17a2b8;
		}
        .sidebar.show {
            transform: translateX(0);
        }
        .sidebar a {
            color: white;
            padding: 10px 15px;
            text-decoration: none;
            display: block;
        }
        /*.sidebar a.active {
            background-color: #17a2b8;
            font-weight: bold;
        }*/
        .sidebar a:hover {
            background-color: #495057;
        }
        .main-content {
            margin-left: 0;
            transition: margin-left 0.3s;
        }
        @media (min-width: 769px) {
            .sidebar {
                transform: translateX(0);
            }
            .main-content {
                margin-left: 150px;
            }
        }
        .loader {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.5);
            display: flex;
            align-items: center;
            justify-content: center;
            color: #fff;
            font-size: 20px;
            font-weight: bold;
            z-index: 2000;
        }
        .loader::before {
            content: '';
            width: 40px;
            height: 40px;
            border: 5px solid #fff;
            border-radius: 50%;
            border-top-color: transparent;
            animation: spin 1s linear infinite;
        }
        @keyframes spin {
            to {
                transform: rotate(360deg);
            }
        }
		.selectpicker {
			font-size: 1.25em; /* Ajusta el tamaño de la fuente */
			
			heigh
		height: 2.5em; /* Ajusta la altura */
			padding: 0.375rem 0.75rem; /* Asegura que el padding sea el mismo que otros campos */
		}
		/* Aumentar tamaño de texto en todos los campos */
		.form-control, .selectpicker, .btn {
			font-size: 3em;  /* Aumenta el tamaño de la fuente */
			min-height: 3em; /* Ajusta la altura si es necesario */
		}

		/* Aumentar tamaño de texto en el selector de loterías */
		.selectpicker {
			font-size: 1.5em;  /* Aumenta el tamaño de la fuente solo en el select */
			height: 1.5em; /* Ajusta la altura */
			padding: 0.375rem 0.75rem; /* Asegura que el padding sea consistente */
		}
		/* Aumentar tamaño de texto en los campos de entrada */
		.form-control, .selectpicker, .btn {
			font-size: 1.5em;  /* Aumenta el tamaño de la fuente */
			min-height: 2.5em; /* Ajusta la altura */
		}

		/* Aumentar tamaño de texto en los campos input específicos */
		input.form-control {
			font-size: 1.5em;  /* Aumenta el tamaño del texto en los inputs */
			height: 3em;       /* Ajusta la altura para que coincida con el tamaño de la fuente */
		}
		/* Aumentar el tamaño del calendario */
		input[type="date"]::-webkit-calendar-picker-indicator {
			width: 60px;  /* Ajusta el ancho */
			height: 60px; /* Ajusta la altura */
			font-size: 4em; /* Cambia el tamaño de la fuente */
		}
		/* Cambiar el tamaño de los números en el calendario */
		.ui-datepicker-calendar td a {
			font-size: 30px;  /* Ajusta el tamaño de los números */
			padding: 10px;    /* Ajusta el espacio alrededor de los números */
		}

		.ui-datepicker {
			font-size: 18px;  /* Ajusta el tamaño de la fuente en el calendario */
		}

		.ui-datepicker-header {
			font-size: 22px;  /* Ajusta el tamaño de la cabecera (mes, año) */
		}
		
		.card-hover {
			transition: transform 0.3s ease, box-shadow 0.3s ease;
		}

		.card-hover:hover {
			transform: scale(1.08);
			box-shadow: 0px 8px 20px rgba(0, 0, 0, 0.15);
		}
		
		#ticket_hoy {
			width: 100%; /* Hace que la tabla ocupe todo el ancho del contenedor */
			table-layout: auto; /* Permite que las columnas se ajusten al contenido */
		}
		#ticket_hoy {
			width: 100%; /* Asegura que la tabla ocupe todo el ancho del modal */
			table-layout: auto; /* Permite que las columnas se ajusten al contenido */
			max-height: 400px; /* Establece una altura máxima para la tabla dentro del modal */
			overflow-y: auto; /* Activa el desplazamiento vertical si el contenido es demasiado grande */
		}		

		/* Ajustar el ancho para la tabla completa */
		#ticket_hoy {
			width: 100%; /* Hacer que la tabla ocupe el 100% del contenedor */
		}

    </style>
</head>
<body>

    <!-- Sidebar (Menú lateral) -->
    <!-- Sidebar (Menú lateral) -->
	<nav class="sidebar" id="sidebar" style="width: 150px;">		
		<ul class="nav flex-column text-center">
			<li class="nav-item">
				<a href="#" aria-label="Ir al Dashboard">
					<i class="fa fa-tachometer-alt" aria-hidden="true"></i> Dashboard
				</a>
			</li>
			<li class="nav-item">
				<a href="ventas.php" class="nav-link">
					<i class="fas fa-file-invoice-dollar fa-2x" aria-hidden="true"></i>
					<div class="text-uppercase" style="font-size: 12px;">Ventas</div>
				</a>
			</li>
			<li class="nav-item">
				<a href="historial.php" class="nav-link">
					<i class="fa fa-history fa-2x" aria-hidden="true"></i>
					<div class="text-uppercase" style="font-size: 12px;">Historial</div>
				</a>
			</li>
			<li class="nav-item">
				<a href="javascript:void(0)" class="nav-link" onclick="cerrar();" aria-label="Cerrar sesión">
					<i class="fas fa-sign-out-alt fa-2x" aria-hidden="true"></i>
					<div class="text-uppercase" style="font-size: 12px;">Cerrar Sesión</div>
				</a>
			</li>
		</ul>
	</nav>
    
    <!-- Contenido Principal -->
    <div class="main-content" id="mainContent">
        <nav class="navbar navbar-expand-lg navbar-light bg-light">
            <div class="container-fluid">
                <button class="navbar-toggler" type="button" aria-label="Toggle navigation" onclick="toggleSidebar()">
                    <span class="navbar-toggler-icon"></span>
                </button>
                <a class="navbar-brand" href="#"><i class="fas fa-tachometer-alt"></i> Panel de pagos</a>
                <div class="collapse navbar-collapse">
                    <ul class="navbar-nav ms-auto">
                        <li class="nav-item">
                            <a class="nav-link active" href="#"><i class="fa fa-store"></i> <?php echo " ".$sucursal; ?></a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link active" href="#"><i class="fa fa-user-secret"></i> <?php echo " ".$usuario; ?></a>                        
                        </li>
                        <li class="nav-item">
                            <a class="nav-link"><i class="fa fa-calendar-check"></i> <span id="fechaActual"></span></a>
                        </li>
                        <li class="nav-item d-none d-md-block">
                            <a class="nav-link"><em class="fas fa-clock text-mac"></em>&nbsp;<span id="horaActual"></span></a>
                        </li>
                    </ul>
                </div>
            </div>
        </nav>      
		
		<div class="col-sm-12 col-md-3 col-lg-3 ms-3">
			<div class="row">
				<div class="col-12">
					<!-- Tarjeta de Ventas Hoy -->
					<div class="row">
						<div class="col-12">
							<div class="card card-hover flex-row align-items-center align-items-stretch border-0" 
								 data-bs-toggle="modal" data-bs-target="#ventasModal" style="cursor: pointer;">
								<div class="col-4 d-flex align-items-center bg-info text-white justify-content-center rounded-left">
									<i class="fas fa-dollar-sign fa-3x"></i>
								</div>
								<div class="col-8 py-3 bg-info-light rounded-end text-center">
									<div class="h2 m-0 text-primary fw-bold">
										<?php
										date_default_timezone_set('America/Guayaquil');
										$fecha_actual = date('Y-m-d'); // Cambio de formato correcto
										//echo $fecha_actual;
										$contn = "SELECT SUM(t.valor) AS totalh
												  FROM tbr_ticket AS t
												  WHERE t.condicion = 1 
													AND t.estado = 2
													AND t.id_usuario = $idusuario
													AND t.fecha_impreso = '$fecha_actual'"; 

										$rn = mysqli_query($conn, $contn);

										if ($rn) {
											$row = mysqli_fetch_assoc($rn);
											$totalh = floatval($row['totalh'] ?? 0);
											echo number_format($totalh, 2, '.', ',');
										} else {
											echo "<span class='text-danger'>Error</span>";
										}
										
										
										?>
									</div>
									<div class="text-uppercase text-muted">Total ventas hoy</div>
								</div>							
							</div>						
						</div>
					</div>					
				</div>
			</div>

			<!-- Encabezado de Ventas Hoy -->
			<div class="content-heading">
				<h5 class="text-dark fw-bold">Ventas Hoy</h5>
				<!--<small class="text-muted">Dashboard</small>-->
			</div>			
		</div>
		<hr>
		<div class="col-sm-12 col-md-3 col-lg-3 ms-3">
			<div class="row">
				<div class="col-12">
					<!-- Tarjeta de Ventas Hoy -->
					<div class="row">
						<div class="col-12">
							<div class="card card-hover flex-row align-items-center align-items-stretch border-0" 
								 data-bs-toggle="modal" data-bs-target="#ventassinModal" style="cursor: pointer;">
								<div class="col-4 d-flex align-items-center bg-info text-white justify-content-center rounded-left">
									<i class="fas fa-dollar-sign fa-3x"></i>
								</div>
								<div class="col-8 py-3 bg-info-light rounded-end text-center">
									<div class="h2 m-0 text-primary fw-bold">
										<?php
										date_default_timezone_set('America/Guayaquil');
										$fecha_actual = date('Y-m-d'); // Cambio de formato correcto
										$contn = "SELECT SUM(t.valor) AS total
												  FROM tbr_ticket AS t
												  WHERE t.condicion = 1 
													AND t.estado >= 2 
													AND t.id_usuario = '$idusuario'
													AND (t.fecha_impreso = '$fecha_actual' AND t.fecha > '$fecha_actual')"; 

										$rn = mysqli_query($conn, $contn);

										if ($rn) {
											$row = mysqli_fetch_assoc($rn);
											$total = floatval($row['total'] ?? 0);
											echo number_format($total, 2, '.', ',');
										} else {
											echo "<span class='text-danger'>Error</span>";
										}
										?>
									</div>
									<div class="text-uppercase text-muted">Total ventas sin jugar</div>
								</div>							
							</div>						
						</div>
					</div>					
				</div>
			</div>
			<div class="content-heading">
				<h5 class="text-dark fw-bold">Ventas sin jugar</h5>
					<!--<small class="text-muted">Dashboard</small>-->			
			</div>
		</div>
		
		<hr>
		<div class="col-sm-12 col-md-3 col-lg-3 ms-3">
			<div class="row">
				<div class="col-12">
					<!-- Tarjeta de Ventas Hoy -->
					<div class="row">
						<div class="col-12">
							<div class="card card-hover flex-row align-items-center align-items-stretch border-0" 
								 data-bs-toggle="modal" data-bs-target="#pendientesModal" style="cursor: pointer;">
								<div class="col-4 d-flex align-items-center bg-info text-white justify-content-center rounded-left">
									<i class="fas fa-dollar-sign fa-3x"></i>
								</div>
								<div class="col-8 py-3 bg-info-light rounded-end text-center">
									<div class="h2 m-0 text-primary fw-bold">
										<?php
										$contn = "SELECT	SUM(ts.premio) AS premiog				
												FROM tbr_sorteo AS s
												INNER JOIN tbr_ticket AS t ON t.numero = s.numero_g AND t.fecha = s.fecha_g
												INNER JOIN tbr_loteria AS l ON l.idloteria = t.id_loteria
												INNER JOIN tbr_ticket_suerte AS ts ON ts.id_ticket = t.idrifa
												INNER JOIN tbr_suerte AS su ON su.idsuerte = s.suerte_g
												WHERE t.condicion = 1 
												AND t.estado = 2 
												AND t.id_usuario = $idusuario
												AND ts.id_suerte = s.suerte_g
												AND t.fecha BETWEEN CURDATE() - INTERVAL 8 DAY AND CURDATE();";
										$rn = mysqli_query($conn, $contn);

										if ($rn) {
											$row = mysqli_fetch_assoc($rn);
											$totalg = floatval($row['premiog'] ?? 0);
											echo number_format($totalg, 2, '.', ',');
										} else {
											echo "<span class='text-danger'>Error</span>";
										}
										?>
									</div>
									<div class="text-uppercase text-muted">Total Ganadores Pendientes</div>
								</div>							
							</div>						
						</div>
					</div>					
				</div>
			</div>
			<div class="content-heading">
				<h5 class="text-dark fw-bold">Ventas Ganadoras Pendientes
					<small>Últimos 8 días</small></h5>				
			</div>
		</div>
		<hr>
		<div class="col-sm-12 col-md-3 col-lg-3 ms-3">
			<div class="row">
				<div class="col-12">
					<!-- Tarjeta de Ventas Hoy -->
					<div class="row">
						<div class="col-12">
							<div class="card card-hover flex-row align-items-center align-items-stretch border-0" 
								 data-bs-toggle="modal" data-bs-target="#pagadoModal" style="cursor: pointer;">
								<div class="col-4 d-flex align-items-center bg-info text-white justify-content-center rounded-left">
									<i class="fas fa-dollar-sign fa-3x"></i>
								</div>
								<div class="col-8 py-3 bg-info-light rounded-end text-center">
									<div class="h2 m-0 text-primary fw-bold">
										<?php
										$contn = "SELECT	SUM(ts.premio) AS premiog				
												FROM tbr_sorteo AS s
												INNER JOIN tbr_ticket AS t ON t.numero = s.numero_g AND t.fecha = s.fecha_g
												INNER JOIN tbr_loteria AS l ON l.idloteria = t.id_loteria
												INNER JOIN tbr_ticket_suerte AS ts ON ts.id_ticket = t.idrifa
												INNER JOIN tbr_suerte AS su ON su.idsuerte = s.suerte_g
												WHERE t.condicion = 1 
												AND t.estado = 3
												AND t.id_usuario = $idusuario
												AND ts.id_suerte = s.suerte_g
												AND t.fecha BETWEEN CURDATE() - INTERVAL 8 DAY AND CURDATE();";
										$rn = mysqli_query($conn, $contn);

										if ($rn) {
											$row = mysqli_fetch_assoc($rn);
											$totalp = floatval($row['premiog'] ?? 0);
											echo number_format($totalp, 2, '.', ',');
										} else {
											echo "<span class='text-danger'>Error</span>";
										}
										?>
									</div>
									<div class="text-uppercase text-muted">Ganadores Pagados</div>
								</div>							
							</div>						
						</div>
					</div>					
				</div>
			</div>
			<div class="content-heading">
				<h5 class="text-dark fw-bold">Ventas Ganadoras Pagadas
					<small>Últimos 8 días</small></h5>				
			</div>
		</div>
		<hr>
		<div class="col-sm-12 col-md-3 col-lg-3 ms-3">
			<div class="row">
				<div class="col-12">
					<!-- Tarjeta de Ventas Hoy -->
					<div class="row">
						<div class="col-12">
							<div class="card card-hover flex-row align-items-center align-items-stretch border-0" 
								 data-bs-toggle="modal" data-bs-target="#caducadoModal" style="cursor: pointer;">
								<div class="col-4 d-flex align-items-center bg-info text-white justify-content-center rounded-left">
									<i class="fas fa-dollar-sign fa-3x"></i>
								</div>
								<div class="col-8 py-3 bg-info-light rounded-end text-center">
									<div class="h2 m-0 text-primary fw-bold">
										<?php
										$contn = "SELECT SUM(ts.premio) AS premiog
													FROM tbr_sorteo AS s
													INNER JOIN tbr_ticket AS t 
														ON t.numero = s.numero_g 
														AND t.fecha = s.fecha_g
													INNER JOIN tbr_loteria AS l 
														ON l.idloteria = t.id_loteria
													INNER JOIN tbr_ticket_suerte AS ts 
														ON ts.id_ticket = t.idrifa
														AND ts.id_suerte = s.suerte_g
													INNER JOIN tbr_suerte AS su 
														ON su.idsuerte = s.suerte_g
													WHERE t.condicion = 1 
													AND t.estado = 2
													AND t.id_usuario = $idusuario
													AND DATE(t.fecha) BETWEEN CURDATE() - INTERVAL 15 DAY AND CURDATE() - INTERVAL 8 DAY;";
										$rn = mysqli_query($conn, $contn);

										if ($rn) {
											$row = mysqli_fetch_assoc($rn);
											$totalc = floatval($row['premiog'] ?? 0);
											echo number_format($totalc, 2, '.', ',');
										} else {
											echo "<span class='text-danger'>Error</span>";
										}
										?>
									</div>
									<div class="text-uppercase text-muted">Caducados No Legalizados</div>
								</div>							
							</div>						
						</div>
					</div>					
				</div>
			</div>
			<div class="content-heading">
				<h5 class="text-dark fw-bold">Ventas Ganadoras Caducadas
					<small>Entre 8 y 15 días</small></h5>				
			</div>
		</div>		
		<hr>
    </div>

    <!-- Cargar scripts al final -->
	
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta2/dist/js/bootstrap-select.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta2/dist/js/i18n/defaults-es_ES.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-lite.min.js"></script>
	<!-- jQuery (necesario para DataTables) -->
	<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
	<!-- DataTables CSS y JS desde CDN -->
	<link rel="stylesheet" href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css">
	<script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
	<script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>
	<!-- Script personalizado -->
	<script src="../../resources/js/menu_hoy.js"></script>
	<script src="../../resources/js/menu_sinjugar.js"></script>
	<script src="../../resources/js/menu_pendiente.js"></script>
	<script src="../../resources/js/menu_pagado.js"></script>	
	<script src="../../resources/js/menu_caducado.js"></script>
	
	<script>
        function cerrar() {
            Swal.fire({
                title: '¿Estás seguro?',
                text: '¿Deseas cerrar sesión?',
                icon: 'warning',
                showCancelButton: true,
                confirmButtonText: 'Sí, cerrar sesión',
                cancelButtonText: 'Cancelar',
                customClass: {
                    confirmButton: 'swal2-confirm',
                    cancelButton: 'swal2-cancel',
                }
            }).then((result) => {
                if (result.isConfirmed) {
                    const loader = document.createElement('div');
                    loader.className = 'loader';
                    loader.textContent = 'Cerrando sesión...';
                    document.body.appendChild(loader);

                    fetch('../../controllers/usuario.php', {
                        method: 'POST',
                        headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
                        body: new URLSearchParams({ boton: 'cerrar' }),
                    })
                    .then((response) => {
                        if (!response.ok) throw new Error('Error en la solicitud');
                        return response.text();
                    })
                    .then(() => location.href = '../index.php')
                    .catch((error) => Swal.fire('Error', error.message, 'error'))
                    .finally(() => loader.remove());
                }
            });
        }

        function toggleSidebar() {
            document.getElementById('sidebar').classList.toggle('show');
        }

        $(document).ready(function () {
            dayjs.locale('es');
            $('#fechaActual').text(dayjs().format('dddd, DD MMMM YYYY'));
            setInterval(function () {
                $('#horaActual').text(dayjs().format('h:mm A'));
            }, 60000); // Actualización de hora cada minuto
        });
    </script>
	<!-- MODAL EXTRA GRANDE -->
	<div class="modal fade" id="ventasModal" tabindex="-1" aria-labelledby="ventasModalLabel" aria-hidden="true">
		<div class="modal-dialog modal-xl modal-dialog-scrollable"> 
			<div class="modal-content">
				<div class="modal-header">
					<h5 class="modal-title" id="ventasModalLabel">Total de ventas hoy: <strong>
						<?php echo '$'.number_format($totalh, 2, '.', ','); ?>
					</strong></h5>
					<button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Cerrar"></button>
				</div>
				<div class="modal-body p-2"> <!-- Quitamos el padding para que la tabla ocupe todo -->
					<div class="table-responsive"> <!-- Contenedor para hacer la tabla adaptable -->
						<table id="ticket_hoy" class="table table-striped w-100 m-0"> <!-- Ancho completo y sin margen -->
							<thead>
								<tr class="text-center">
									<th>Codigo <i class="fas fa-sort-numeric-down"></i></th>
									<th>Loteria <i class="fas fa-comments"></i></th>
									<th>Número <i class="fas fa-list-ol"></i></th>
									<th>Fecha Realizado <i class="fas fa-calendar"></i></th>
									<th>Fecha Juega <i class="fas fa-calendar-check"></i></th>
									<th>Valor <i class="fas fa-dollar-sign"></i></th>
									<th>Negocio <i class="fas fa-calendar-check"></i></th>
									<th>Usuario <i class="fas fa-user"></i></th>
									<th>Porcentaje <i class="fas fa-user"></i></th>
									<th>Valor a pagar <i class="fas fa-dollar-sign"></i></th>
									<th>Acción</th>
								</tr>
							</thead>
							<tbody>
								<!-- Aquí puedes cargar más datos dinámicamente -->
							</tbody>
							<tfoot>
								<tr>
									<th colspan="5">Totales</th>
									<th id="total-value">$0.00</th>
									<th></th>
								</tr>
							</tfoot>
						</table>
					</div>
				</div>
				<div class="modal-footer">
					<button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cerrar</button>
				</div>
			</div>
		</div>
	</div>
	
	<div class="modal fade" id="ventassinModal" tabindex="-1" aria-labelledby="ventasModalLabel" aria-hidden="true">
		<div class="modal-dialog modal-xl modal-dialog-scrollable"> 
			<div class="modal-content">
				<div class="modal-header">
					<h5 class="modal-title" id="ventasModalLabel">Total de ventas hoy: <strong>
						<?php echo '$'.number_format($total, 2, '.', ','); ?>
					</strong></h5>
					<button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Cerrar"></button>
				</div>
				<div class="modal-body p-2"> <!-- Quitamos el padding para que la tabla ocupe todo -->
					<div class="table-responsive"> <!-- Contenedor para hacer la tabla adaptable -->
						<table id="ticket_sin" class="table table-striped w-100 m-0"> <!-- Ancho completo y sin margen -->
							<thead>
								<tr class="text-center">
									<th>Codigo <i class="fas fa-sort-numeric-down"></i></th>
									<th>Loteria <i class="fas fa-comments"></i></th>
									<th>Número <i class="fas fa-list-ol"></i></th>
									<th>Fecha Realizado <i class="fas fa-calendar"></i></th>
									<th>Fecha Juega <i class="fas fa-calendar-check"></i></th>
									<th>Valor <i class="fas fa-dollar-sign"></i></th>
									<th>Negocio <i class="fas fa-calendar-check"></i></th>
									<th>Usuario <i class="fas fa-user"></i></th>
									<th>Porcentaje <i class="fas fa-user"></i></th>
									<th>Valor a pagar <i class="fas fa-dollar-sign"></i></th>
																	
								</tr>
							</thead>
							<tbody>
								<!-- Aquí puedes cargar más datos dinámicamente -->
							</tbody>
							<tfoot>
								<tr>
									<th colspan="5">Totales</th>
									<th id="total-value">$0.00</th>
									<th></th>
								</tr>
							</tfoot>
						</table>
					</div>
				</div>
				<div class="modal-footer">
					<button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cerrar</button>
				</div>
			</div>
		</div>
	</div>


	<!-- MODAL EXTRA GRANDE -->
	<div class="modal fade" id="pendientesModal" tabindex="-1" aria-labelledby="ventasModalLabel" aria-hidden="true">
		<div class="modal-dialog modal-xl modal-dialog-scrollable"> <!-- Modal extra grande y con desplazamiento -->
			<div class="modal-content">
				<div class="modal-header">
					<h5 class="modal-title" id="ventasModalLabel">Ventas Ganadoras Pendientes Últimos 8 días: <strong>$
						<?php echo number_format($totalg, 2, '.', ','); ?>
					</strong></h5>
					<button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Cerrar"></button>
				</div>
				<div class="modal-body p-2"> <!-- Quitamos el padding para que la tabla ocupe todo -->
					<div class="table-responsive"> <!-- Contenedor para hacer la tabla adaptable -->
						<table id="ticket_pend" class="table table-striped w-100 m-0"> <!-- Ancho completo y sin margen -->
							<thead>
								<tr class="text-center">
									<th> Codigo<i class="fas fa-sort-numeric-down"></i> </th>
									<th> Loteria<i class="fas fa-comments"></i> </th>
									<th> Número<i class="fas fa-list-ol"></i> </th>
									<th> Fecha Realizado<i class="fas fa-calendar"></i> </th>
									<th> Fecha Juega<i class="fas fa-calendar-check"></i> </th>
									<th> Valor<i class="fas fa-dollar-sign"></i> </th>								
									<th> Negocio<i class="fas fa-calendar-check"></i> </th>
									<th> Usuario<i class="fas fa-user"></i> </th>
									<th> Porcentaje<i class="fas fa-user"></i> </th>
									<th> Valor a pagar<i class="fas fa-dollar-sign"></i> </th>									
								</tr>
							</thead>
							<tbody>                            
								<!-- Aquí puedes cargar más datos dinámicamente -->
							</tbody>
							<tfoot>
								<tr>
									<th colspan="3">Totales</th>
									<th id="total-value">$0.00</th>
									<th></th>
								</tr>
							</tfoot>
						</table>
					</div>
				</div>
				<div class="modal-footer">
					<button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cerrar</button>
				</div>
			</div>
		</div>
	</div>
	
	<!-- MODAL EXTRA GRANDE -->
	<div class="modal fade" id="pagadoModal" tabindex="-1" aria-labelledby="ventasModalLabel" aria-hidden="true">
		<div class="modal-dialog modal-xl modal-dialog-scrollable"> <!-- Modal extra grande y con desplazamiento -->
			<div class="modal-content">
				<div class="modal-header">
					<h5 class="modal-title" id="ventasModalLabel">Ventas Ganadoras Pagadas Últimos 8 días: <strong>$
						<?php echo number_format($totalp, 2, '.', ','); ?>
					</strong></h5>
					<button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Cerrar"></button>
				</div>
				<div class="modal-body">
					
					<!-- Contenido adicional dentro del modal -->
					<table id="ticket_pagado" class="table table-striped w-100 m-0"> <!-- Ancho completo y sin margen -->
						<thead>
							<tr class="text-center">
								<th> Codigo<i class="fas fa-sort-numeric-down"></i> </th>
								<th> Loteria<i class="fas fa-comments"></i> </th>
								<th> Número<i class="fas fa-list-ol"></i> </th>
								<th> Fecha Realizado<i class="fas fa-calendar"></i> </th>
								<th> Fecha Juega<i class="fas fa-calendar-check"></i> </th>
								<th> Valor<i class="fas fa-dollar-sign"></i> </th>								
								<th> Negocio<i class="fas fa-calendar-check"></i> </th>
								<th> Usuario<i class="fas fa-user"></i> </th>
								<th> Porcentaje<i class="fas fa-user"></i> </th>
								<th> Valor a pagar<i class="fas fa-dollar-sign"></i> </th>								
							</tr>
						</thead>
						<tbody>                            
							<!-- Aquí puedes cargar más datos dinámicamente -->
						</tbody>
						<tfoot>
							<tr>
								<th colspan="3">Totales</th>
								<th id="total-value">$0.00</th>
								<th></th>
							</tr>
						</tfoot>
					</table>

				</div>
				<div class="modal-footer">
					<button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cerrar</button>
				</div>
			</div>
		</div>
	</div>
	<!-- MODAL EXTRA GRANDE -->
	<div class="modal fade" id="caducadoModal" tabindex="-1" aria-labelledby="ventasModalLabel" aria-hidden="true">
		<div class="modal-dialog modal-xl modal-dialog-scrollable"> <!-- Modal extra grande y con desplazamiento -->
			<div class="modal-content">
				<div class="modal-header">
					<h5 class="modal-title" id="ventasModalLabel">Ventas Ganadoras Caducadas Entre 8 y 15 días: <strong>$
						<?php echo number_format($totalc, 2, '.', ','); ?>
					</strong></h5>
					<button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Cerrar"></button>
				</div>
				<div class="modal-body">
					
					<!-- Contenido adicional dentro del modal -->
					<table id="table_caducado" class="table table-striped w-100 m-0"> <!-- Ancho completo y sin margen -->
						<thead>
							<tr class="text-center">
								<th> Codigo<i class="fas fa-sort-numeric-down"></i> </th>
								<th> Loteria<i class="fas fa-comments"></i> </th>
								<th> Número<i class="fas fa-list-ol"></i> </th>
								<th> Fecha Realizado<i class="fas fa-calendar"></i> </th>
								<th> Fecha Juega<i class="fas fa-calendar-check"></i> </th>
								<th> Valor<i class="fas fa-dollar-sign"></i> </th>								
								<th> Negocio<i class="fas fa-calendar-check"></i> </th>
								<th> Usuario<i class="fas fa-user"></i> </th>
								<th> Porcentaje<i class="fas fa-user"></i> </th>
								<th> Valor a pagar<i class="fas fa-dollar-sign"></i> </th>								
							</tr>
						</thead>
						<tbody>                            
							<!-- Aquí puedes cargar más datos dinámicamente -->
						</tbody>
						<tfoot>
							<tr>
								<th colspan="5">Totales</th>
								<th id="total-value">$0.00</th>
								<th></th>
							</tr>
						</tfoot>
					</table>

				</div>
				<div class="modal-footer">
					<button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cerrar</button>
				</div>
			</div>
		</div>
	</div>
	
</body>
</html>
