<?php
	session_start();
	include("conex.php");

	if (!isset($_SESSION['idusuario'])) {
		echo json_encode(["error" => "Error: Sesión no iniciada."]);
		exit();
	}

	$id_usuario = $_SESSION['idusuario'];
	$sucursal_id = $_SESSION['sucursal'] ?? null;
	$my_ip = $_SERVER["REMOTE_ADDR"];
	date_default_timezone_set('America/Guayaquil');
	$fecha_actual = date('Y-m-d'); // Formato correcto para MySQL
	$time_actual = date("H:i:s");

	// Conexión a la base de datos
	if (!$conn) 
	{
		echo json_encode(["error" => "Error de conexión a la base de datos."]);
		exit();
	}

	// Sanitización y validación de datos
	$date = filter_input(INPUT_POST, 'date', FILTER_SANITIZE_STRING);
	$loterias = filter_input(INPUT_POST, 'loterias', FILTER_VALIDATE_INT) ?: 0;
	$number = filter_input(INPUT_POST, 'number', FILTER_VALIDATE_INT) ?: 0;
	$valor = filter_input(INPUT_POST, 'valor', FILTER_VALIDATE_FLOAT) ?: 0.00;
	$condicion = 1;
	$estado = 1;
	$suma_valor = 0;
	$cupo_maximo = 0;
	
	// Validación de fecha
	$fecha_valida = DateTime::createFromFormat('Y-m-d', $date) !== false;
	if (!$fecha_valida || $loterias <= 0 || $number <= 0 || $valor <= 0) 
	{
		echo json_encode(["error" => "Error: Todos los campos son obligatorios y deben tener valores válidos."]);
		exit();
	}

	// Consultar cupo máximo del usuario
	$query = "SELECT cupo 
				FROM tbr_sucursal 
				WHERE idsucursal = ?";
	$stmt = mysqli_prepare($conn, $query);
	mysqli_stmt_bind_param($stmt, "i", $sucursal_id);
	mysqli_stmt_execute($stmt);
	$result = mysqli_stmt_get_result($stmt);
	if ($row = mysqli_fetch_assoc($result)) {
		$cupo_maximo = $row['cupo'];
	}
	mysqli_stmt_close($stmt);

	// Consultar el total apostado hasta ahora
	$query = "SELECT IFNULL(SUM(valor), 0) AS suma_valor 
			FROM tbr_ticket 
			WHERE DATE(fecha) = CURDATE() AND condicion = 1 AND numero = ? AND id_usuario =?";
	$stmt = mysqli_prepare($conn, $query);
	mysqli_stmt_bind_param($stmt, "ii", $number,$id_usuario);
	mysqli_stmt_execute($stmt);
	$result = mysqli_stmt_get_result($stmt);
	if ($row = mysqli_fetch_assoc($result)) 
	{
		$suma_valor = $row['suma_valor'];
	}
	mysqli_stmt_close($stmt);

	// Validar si la nueva apuesta supera el cupo máximo
	if (($suma_valor + $valor) > $cupo_maximo) 
	{
		echo json_encode(["error" => "Error: No puedes superar el cupo máximo de '$cupo_maximo'."]);
		exit();
	}

	// Generar código único
	function generateCodigo($length = 8) 
	{
		//return substr(bin2hex(random_bytes(4)), 0, $length);
		return substr(str_shuffle(str_repeat('01234567', $length)), 0, $length);
	}
	$codigo = generateCodigo();

	// Insertar ticket en la base de datos
	$sql_insert = "INSERT INTO tbr_ticket (fecha_impreso, fecha, id_loteria, numero, valor, id_usuario, codigo, estado, condicion) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)";
	$stmt = mysqli_prepare($conn, $sql_insert);
	mysqli_stmt_bind_param($stmt, "ssiiddiss", $fecha_actual, $date, $loterias, $number, $valor, $id_usuario, $codigo, $estado, $condicion);
	$insert_success = mysqli_stmt_execute($stmt);

	if (!$insert_success) 
	{
		echo json_encode(["error" => "Error al insertar el ticket: " . mysqli_error($conn)]);
		exit();
	}

	$idrifa = mysqli_insert_id($conn);
	mysqli_stmt_close($stmt);

	if ($idrifa === 0) 
	{
		echo json_encode(["error" => "Error: No se pudo obtener el ID del ticket."]);
		exit();
	}

	// Confirmación de éxito
	//echo json_encode(["success" => true, "message" => "Éxito: Ticket guardado correctamente.", "ticket_id" => $idrifa, "codigo" => $codigo], JSON_UNESCAPED_UNICODE);
?>
