<?php
session_start();
include("conex.php");

// Verifica si las variables de sesión están definidas
if (empty($_SESSION['idusuario']) || empty($_SESSION['usuario']) || empty($_SESSION['sucursal'])) {
    header('Location: index.php');
    exit(); // Evitar continuar ejecutando el script
}

$idusuario = htmlspecialchars($_SESSION['idusuario'], ENT_QUOTES, 'UTF-8');
$usuario = htmlspecialchars($_SESSION['usuario'], ENT_QUOTES, 'UTF-8');
$sucursal = htmlspecialchars($_SESSION['sucursal'], ENT_QUOTES, 'UTF-8');
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Sistema de Gestión</title>
    <link rel="shortcut icon" href="../resources/img/crud.ico">
    <!-- Bootstrap CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <!-- Estilos personalizados -->
    <style>
    body {
        background-color: #f4f6f9;
        padding-top: 60px;
    }

    .topbar {
        width: 100%;
        height: 60px;
        background: #343a40;
        color: white;
        display: flex;
        align-items: center;
        justify-content: space-between;
        padding: 0 20px;
        position: fixed;
        top: 0;
        left: 0;
        z-index: 1000;
    }

    .sidebar {
        width: 250px;
        background: #343a40;
        padding: 20px;
        height: 100vh;
        position: fixed;
        left: 0;
        top: 60px;
        display: flex;
        flex-direction: column;
        align-items: flex-start;
        transition: width 0.3s;
    }

    .sidebar a {
        color: white;
        text-decoration: none;
        padding: 12px;
        display: flex;
        align-items: center;
        width: 100%;
        transition: background 0.3s, transform 0.2s;
        border-radius: 8px;
    }

    .sidebar a i {
        margin-right: 15px; /* Agrega espacio entre el ícono y el texto */
    }

    .sidebar .submenu {
        display: none;
        padding-left: 20px;
        list-style: none;
        margin: 0;
        font-size: 14px;
    }

    .sidebar .submenu li {
        padding: 8px 0;
    }

    .sidebar .submenu-toggle.active + .submenu {
        display: block;
    }

    .sidebar a:hover, .sidebar a.active {
        background: #495057;
        transform: scale(1.05);
    }

    .topbar .info {
        display: flex;
        gap: 20px;
        margin-left: auto;
    }

    .main-content {
        margin-left: 250px;
        padding: 1rem;
        transition: margin-left 0.3s;
    }

    .sidebar.collapsed {
        width: 80px;
    }

    .sidebar.collapsed a span {
        display: none;
    }

    .toggle-btn {
        cursor: pointer;
        margin-right: 10px;
    }

    .submenu a {
        font-size: 16px;
        padding-left: 20px;
    }
	.sidebar a i {
        margin-right: 10px;
    }

    </style>
</head>
<body>

<!-- Barra Superior -->
<div class="topbar">
    <div class="toggle-btn" onclick="toggleSidebar()">
        <i class="fas fa-bars"></i>
    </div>
    <span style="margin-left: 20px;">Sistema de Gestión</span>
    <div class="info">
        <span><?php echo $usuario; ?></span>
        <span id="fechaActual"></span>
        <span id="horaActual"></span>
    </div>
</div>

<!-- Sidebar -->
<?php include("menu.php"); ?>

<!-- Contenido Principal -->
<div class="main-content" id="mainContent">
    <p>Bienvenido al panel de control.</p>
</div>

<!-- Scripts -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>

<script>
    function cerrar() {
        Swal.fire({
            title: '¿Estás seguro?',
            text: '¿Deseas cerrar sesión?',
            icon: 'warning',
            showCancelButton: true,
            confirmButtonText: 'Sí, cerrar sesión',
            cancelButtonText: 'Cancelar',
        }).then((result) => {
            if (result.isConfirmed) {
                fetch('../../controllers/usuario.php', {
                    method: 'POST',
                    headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
                    body: new URLSearchParams({ boton: 'cerrar' }),
                })
                .then(response => response.ok ? location.href = 'index.php' : Swal.fire('Error', 'No se pudo cerrar sesión', 'error'))
                .catch(error => Swal.fire('Error', 'Hubo un problema: ' + error.message, 'error'));
            }
        });
    }

    function toggleSidebar() {
        const sidebar = document.getElementById('sidebar');
        const mainContent = document.getElementById('mainContent');
        sidebar.classList.toggle('collapsed');
        mainContent.style.marginLeft = sidebar.classList.contains('collapsed') ? '80px' : '250px';
    }

    document.querySelectorAll('.submenu-toggle').forEach((element) => {
        element.addEventListener('click', function() {
            const submenu = this.nextElementSibling;
            submenu.classList.toggle('active');
            this.classList.toggle('active');
        });
    });

    function actualizarHora() {
        const ahora = new Date();
        const opcionesFecha = { weekday: 'long', year: 'numeric', month: 'long', day: 'numeric' };
        const opcionesHora = { hour: '2-digit', minute: '2-digit', second: '2-digit' };
        document.getElementById('fechaActual').textContent = ahora.toLocaleDateString('es-ES', opcionesFecha);
        document.getElementById('horaActual').textContent = ahora.toLocaleTimeString('es-ES', opcionesHora);
    }
    setInterval(actualizarHora, 1000);
    actualizarHora();
</script>

</body>
</html>
