<?php
session_start();

// Verificar sesión
if (!isset($_SESSION['idusuario'], $_SESSION['usuario'], $_SESSION['sucursal'])) {
    header('Location: index.php');
    exit();
}

$idusuario = (int) $_SESSION['idusuario']; // Forzar entero para seguridad
$sucursal_id = $_SESSION['sucursal'] ?? null;

include("conex.php"); // Conexión a la base de datos

header("Content-Type: application/json");
date_default_timezone_set('America/Santo_Domingo'); // Ajustar la zona horaria

// Verificar conexión a la base de datos
if (!$conn) {
    http_response_code(500);
    echo json_encode(["error" => "Error de conexión a la base de datos."]);
    exit();
}

// Obtener la fecha actual
$fecha_hoy = date('Y-m-d');

// Obtener el cupo máximo del usuario
$query_cupo = "SELECT cupo_maximo FROM tbr_usuario WHERE idusuario = ? AND activo = 1 AND condicion = 1";
$stmt_cupo = mysqli_prepare($conn, $query_cupo);
mysqli_stmt_bind_param($stmt_cupo, "i", $idusuario);
mysqli_stmt_execute($stmt_cupo);
$result_cupo = mysqli_stmt_get_result($stmt_cupo);
$cupo = ($row = mysqli_fetch_assoc($result_cupo)) ? (int) $row['cupo_maximo'] : 0;
mysqli_stmt_close($stmt_cupo);

// Verificar que la sucursal es válida
if (!$sucursal_id) {
    http_response_code(400);
    echo json_encode(["error" => "Sucursal no válida."]);
    exit();
}

// Consulta para obtener los números que superan el cupo máximo
$query = "SELECT t.numero, SUM(t.valor) AS total_valor, l.loteria
          FROM tbr_ticket AS t
          INNER JOIN tbr_loteria AS l ON l.idloteria = t.id_loteria
          INNER JOIN tbr_usuario AS u ON u.idusuario = t.id_usuario
          WHERE t.condicion = 1 
          AND t.estado = 2 
          AND u.id_sucursal = ?
          AND DATE(t.fecha) = ?
          GROUP BY t.numero, l.loteria
          HAVING total_valor >= ?
          ORDER BY t.numero ASC";

$stmt = mysqli_prepare($conn, $query);
mysqli_stmt_bind_param($stmt, "isi", $sucursal_id, $fecha_hoy, $cupo);
mysqli_stmt_execute($stmt);
$result = mysqli_stmt_get_result($stmt);

// Verificar si hay error en la consulta
if (!$result) {
    http_response_code(500);
    echo json_encode(["error" => "Error en la consulta."]);
    exit();
}

// Construcción del array de respuesta
$numeros = [];
while ($row = mysqli_fetch_assoc($result)) {
    $numeros[] = [
        'numero' => str_pad($row['numero'], 3, '0', STR_PAD_LEFT), // Asegurar 3 dígitos
        'loteria' => $row['loteria']
    ];
}

// Responder en JSON
echo json_encode([
    "numeros_superan_cupo" => $numeros
], JSON_UNESCAPED_UNICODE);

// Cerrar conexiones
mysqli_stmt_close($stmt);
mysqli_close($conn);
?>
