<?php
	include("../conex.php");
	session_start();

	// Verifica si la sesión está activa
	if (!isset($_SESSION['idusuario'], $_SESSION['usuario'], $_SESSION['sucursal'])) 
	{
		header('Location: index.php');
		exit();
	}

	date_default_timezone_set('America/Guayaquil');
	setlocale(LC_TIME, "es_ES.UTF-8"); // Configurar idioma español en sistemas compatibles

	$idusuario = htmlspecialchars($_SESSION['idusuario']);
	$usuario = htmlspecialchars($_SESSION['usuario']);
	$sucursal = htmlspecialchars($_SESSION['sucursal']);
	$fecha_actual = strftime('%A, %d de %B de %Y'); // Formato en español
	$hora_actual = date("H:i:s");

	// Consulta optimizada
	$query = "SELECT t.idrifa, t.fecha, t.numero, t.valor, t.codigo, l.loteria
			  FROM tbr_ticket AS t
			  INNER JOIN tbr_loteria AS l ON l.idloteria = t.id_loteria
			  WHERE t.id_usuario = $idusuario AND t.key IS NULL AND t.condicion = 1";
	$result = mysqli_query($conn, $query);
	$tickets = mysqli_fetch_all($result, MYSQLI_ASSOC);

	// Función para generar clave única
	if (!function_exists('generateKey')) 
	{
		function generateKey($length = 11) 
		{
			return substr(str_shuffle(str_repeat('0123456789', $length)), 0, $length);
		}
	}

	// Directorio para códigos QR
	$PNG_TEMP_DIR = __DIR__ . '/temp/';
	$PNG_WEB_DIR = 'temp/';
	include "qrlib.php";

	if (!file_exists($PNG_TEMP_DIR)) 
	{
		mkdir($PNG_TEMP_DIR, 0777, true);
	}
?>
<!DOCTYPE html>
<html lang="es">
	<head>
		<meta charset="utf-8">
		<meta http-equiv="X-UA-Compatible" content="IE=edge">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<title>Generar Ticket</title>
		<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css">
		<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
		<script src="https://cdn.jsdelivr.net/npm/dayjs@1.10.4/dayjs.min.js"></script>
		<script src="https://cdn.jsdelivr.net/npm/dayjs@1.10.4/locale/es.js"></script>
		<style>
			body { text-align: center; }
			.ticket-container { max-width: 400px; margin: auto; border: 1px solid #ccc; padding: 20px; }
			.numero { font-size: 34px; font-weight: bold; }
			.loteria, .valor, .premios { font-size: 18px; font-weight: bold; }
			.key, .nota { font-size: 14px; font-weight: bold; }
			.premios-container { display: flex; flex-wrap: wrap; justify-content: center; }
			.premios-container div { width: 100%; padding: 5px; }
			.linea-separadora { border-top: 2px dashed black; margin: 20px 0; } /* Línea separadora entre tickets */
			
			
			.premios-container {
				display: flex;
				flex-direction: column; /* Coloca los premios en columna */
				
			}

			.premio-item {
				display: flex;
				justify-content: space-between; /* Espacio entre suerte y valor/detalle */
				margin-bottom: 5px; /* Espacio entre los elementos */
				
			}

			.suerte {
				font-weight: bold; /* Resalta la suerte */
				font-size: 1.0em; /* Aumenta el tamaño de la fuente para la suerte */
				line-height: 0; /* Ajusta el interlineado para la suerte */				
				text-align: right; /* Alinea el texto a la derecha */
				flex: 1; /* Permite que el elemento ocupe el espacio disponible */
				
			}

			.valor-detalle {
				color: #0a0a0a; /* Color más suave para el valor y detalle */
				font-size: 1.0em; /* Aumenta el tamaño de la fuente para el valor y detalle */
				margin-left: 40px; /* Agrega espacio a la izquierda del valor/detalle */
				line-height: 0; /* Ajusta el interlineado para el valor/detalle */
				text-align: left; /* Alinea el texto a la derecha */
				flex: 1; /* Permite que el elemento ocupe el espacio disponible */
			}


		</style>
	</head>
	<body>
		<div class="container">
			<div class="ticket-container">
				<img src="logo.png" alt="Logo" style="max-width: 200px;">
				<h4 class="usua">IMPRESO POR: <?= htmlspecialchars($usuario) ?></h4>
				<h5 class="fecha"><?= htmlspecialchars($fecha_actual) ?></h5>
				<h5 class="hora"><?= htmlspecialchars($hora_actual) ?></h5>

				<?php 
					foreach ($tickets as $ticket): 
					// Generar una clave única para cada ticket
					$key = generateKey();

					// Guardar la clave en la base de datos
					$sql = "UPDATE tbr_ticket 
							SET estado = 2, `key` = '$key' 
							WHERE idrifa = {$ticket['idrifa']}";
					mysqli_query($conn, $sql);

					// Generar código QR
					$filename = $PNG_TEMP_DIR . 'ticket_' . md5($key) . '.png';
					QRcode::png($key, $filename, 'L', 3, 2);
				?>

				<h3 class="title">Nro.:</h3>
				<h4 class="numero"><?= str_pad(htmlspecialchars($ticket['numero']), 3, '0', STR_PAD_LEFT) ?></h4>
				<h5 class="loteria"><?= htmlspecialchars($ticket['loteria']) ?></h5>
				<h5 class="valor">$<?= $valo = number_format($ticket['valor'], 2) ?></h5>

				<div class="premios-container">
					<?php
						// Consulta para obtener los premios del usuario
						$query = "SELECT s.idsuerte, s.suerte, s.valor, p.detalle 
								  FROM tbr_premio AS p
								  INNER JOIN tbr_suerte AS s ON s.idsuerte = p.id_suerte
								  WHERE p.id_usuario = ?";

						// Preparar la consulta
						$stmt = mysqli_prepare($conn, $query);
						
						// Enlazar el parámetro
						mysqli_stmt_bind_param($stmt, "i", $idusuario);
						
						// Ejecutar la consulta
						mysqli_stmt_execute($stmt);
						
						// Obtener el resultado
						$result = mysqli_stmt_get_result($stmt);

						// Recorrer los resultados y mostrarlos
						while ($row = mysqli_fetch_assoc($result)) 
						{
							$valort = number_format($row['valor'] * $valo, 2);
							$idsuerte = $row['idsuerte'];
							
							echo "<div class='premio-item'>
									<p class='suerte'><strong>{$row['suerte']}</strong></p>
									<p class='valor-detalle'><strong>\${$valort} - {$row['detalle']}</strong></p>
								  </div>";
								  
								// Definir la condición
							$condicion = 1; // O el valor que corresponda en tu lógica

							$sql_insert = "INSERT INTO tbr_ticket_suerte (id_suerte, premio, id_ticket, condicion) VALUES (?, ?, ?, ?)";
							$stmt = mysqli_prepare($conn, $sql_insert);

							// Aquí se deben pasar las variables correctamente sin usar llaves para el valor de `ticket['idrifa']`
							mysqli_stmt_bind_param($stmt, "idis", $idsuerte, $valort, $ticket['idrifa'], $condicion);
							$insert_success = mysqli_stmt_execute($stmt);

							if (!$insert_success) {
								echo json_encode(["error" => "Error al insertar la suerte: " . mysqli_error($conn)]);
								exit();
							}
  
						}
						
						// Cerrar la declaración
						mysqli_stmt_close($stmt);
					?>
				</div>

				<h5 class="loteria">Código: <?= htmlspecialchars($ticket['codigo']) ?></h5>

				<div>
					<img src="<?= htmlspecialchars($PNG_WEB_DIR . basename($filename)) ?>" alt="Código QR" style="max-width: 150px;">
				</div>

				<h5 class="key">KEY: <?= htmlspecialchars($key) ?></h5>
				<h5 class="nota">SI NO GANAS, TIENES OTRA OPORTUNIDAD. LLEVA TU TICKET PARA EL SORTEO MENSUAL.</h5>
				<h5 class="nota">Nota: El equivalente en electrodoméstico y víveres.</h5>
				<h5 class="nota">Caducidad: 8 días.</h5>

				<div class="linea-separadora"></div> <!-- Línea separadora entre tickets -->

				<?php endforeach; ?>
			</div>
		</div>

		<script>
			$(document).ready(function () {
				dayjs.locale('es');
				$('.fecha').text(dayjs().format('dddd, DD MMMM YYYY'));
				$('.hora').text(dayjs().format('HH:mm'));
			});

			// Imprimir automáticamente
			// window.print();
		</script>
	</body>
</html>
