<?php
	session_start();
	include("conex.php");
	// Verifica si las variables de sesión están definidas
	if (!isset($_SESSION['idusuario'], $_SESSION['usuario'], $_SESSION['sucursal'])) {
		header('Location: index.php'); // Redirige al login si no hay sesión activa
		exit();
	}

	$idusuario = htmlspecialchars($_SESSION['idusuario']);
	$usuario = htmlspecialchars($_SESSION['usuario']);
	$sucursal_id = $_SESSION['sucursal'] ?? null;

	if (!is_numeric($sucursal_id)) {
		die("ID de sucursal inválido");
	}

	// Verifica que la conexión esté establecida
	if (!isset($conn) || $conn === null) {
		die("Error: No se pudo establecer la conexión a la base de datos.");
	}

	// Consulta preparada
	$query = "SELECT sucursal FROM tbr_sucursal WHERE idsucursal = ?";
	$stmt = mysqli_prepare($conn, $query);

	if ($stmt) {
		mysqli_stmt_bind_param($stmt, "i", $sucursal_id);
		mysqli_stmt_execute($stmt);
		$result = mysqli_stmt_get_result($stmt);
		
		if ($row = mysqli_fetch_assoc($result)) {
			$sucursal = $row['sucursal'];
		} else {
			die("Sucursal no encontrada.");
		}
		
		mysqli_stmt_close($stmt);
	} else {
		die("Error en la preparación de la consulta.");
	}



?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="Panel de administración para gestionar usuarios y configuraciones.">
    <meta name="keywords" content="panel, administración, usuarios, reportes, gestión">
    <title>Sistema de Gestión</title>
    <link rel="shortcut icon" href="../resources/img/crud.ico">
    
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">

    <!-- Font Awesome -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">

    <!-- Bootstrap Select CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta2/dist/css/bootstrap-select.min.css">

    <!-- Summernote CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-lite.min.css">

    <!-- SweetAlert2 CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/sweetalert2@11/dist/sweetalert2.min.css">

    <!-- jQuery -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

    <!-- Day.js -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/dayjs/1.11.7/dayjs.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/dayjs/1.11.7/locale/es.min.js"></script>

    <!-- Bootstrap JS Bundle (incluye Popper.js) -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <!-- Bootstrap Select JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta2/dist/js/bootstrap-select.min.js"></script>

    <!-- Summernote JS -->
    <script src="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-lite.min.js"></script>

    <!-- SweetAlert2 JS -->
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>

    <!-- DataTables CSS -->
    <link rel="stylesheet" href="https://cdn.datatables.net/1.13.6/css/dataTables.bootstrap5.min.css">

    <!-- DataTables JS -->
    <script src="https://cdn.datatables.net/1.13.6/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.13.6/js/dataTables.bootstrap5.min.js"></script>

	
	<style>
		 /* Aplicar un tamaño de fuente y altura mínima global para el formulario */
		.form-control, .selectpicker, .btn {
			font-size: 2em;
			min-height: 2em;
		}
        body {
            background-color: #f4f6f9;
        }
        .navbar {
            margin-bottom: 20px;
        }
        .content {
            padding: 1rem;
        }
        .sidebar {
			width: 250px;
			background: #343a40;
			padding: 20px;
			height: 100vh;
			position: fixed;
			left: 0;
			top: 0;
			display: flex;
			flex-direction: column;
			align-items: center;
		}

		.sidebar h4 {
			font-size: 1.2rem;
		}

		.sidebar a {
			color: white;
			text-decoration: none;
			padding: 15px;
			width: 100%;
			display: flex;
			flex-direction: column;
			align-items: center;
			transition: background 0.3s, transform 0.2s;
		}

		.sidebar a i {
			margin-bottom: 8px;
		}

		.sidebar a:hover {
			background: rgba(255, 255, 255, 0.1);
			transform: scale(1.05);
			border-radius: 8px;
		}

		.sidebar .active {
			font-weight: bold;
			color: #17a2b8;
		}
        .sidebar.show {
            transform: translateX(0);
        }
        .sidebar a {
            color: white;
            padding: 10px 15px;
            text-decoration: none;
            display: block;
        }
        /*.sidebar a.active {
            background-color: #17a2b8;
            font-weight: bold;
        }*/
        .sidebar a:hover {
            background-color: #495057;
        }
        .main-content {
            margin-left: 0;
            transition: margin-left 0.3s;
        }
        @media (min-width: 769px) {
            .sidebar {
                transform: translateX(0);
            }
            .main-content {
                margin-left: 150px;
            }
        }
        .loader {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background: rgba(0, 0, 0, 0.5);
            display: flex;
            align-items: center;
            justify-content: center;
            color: #fff;
            font-size: 20px;
            font-weight: bold;
            z-index: 2000;
        }
        .loader::before {
            content: '';
            width: 40px;
            height: 40px;
            border: 5px solid #fff;
            border-radius: 50%;
            border-top-color: transparent;
            animation: spin 1s linear infinite;
        }
        @keyframes spin {
            to {
                transform: rotate(360deg);
            }
        }
		.selectpicker {
			font-size: 1.25em; /* Ajusta el tamaño de la fuente */
			
			heigh
		height: 2.5em; /* Ajusta la altura */
			padding: 0.375rem 0.75rem; /* Asegura que el padding sea el mismo que otros campos */
		}
		/* Aumentar tamaño de texto en todos los campos */
		.form-control, .selectpicker, .btn {
			font-size: 3em;  /* Aumenta el tamaño de la fuente */
			min-height: 3em; /* Ajusta la altura si es necesario */
		}

		/* Aumentar tamaño de texto en el selector de loterías */
		.selectpicker {
			font-size: 1.5em;  /* Aumenta el tamaño de la fuente solo en el select */
			height: 1.5em; /* Ajusta la altura */
			padding: 0.375rem 0.75rem; /* Asegura que el padding sea consistente */
		}
		/* Aumentar tamaño de texto en los campos de entrada */
		.form-control, .selectpicker, .btn {
			font-size: 1.5em;  /* Aumenta el tamaño de la fuente */
			min-height: 2.5em; /* Ajusta la altura */
		}

		/* Aumentar tamaño de texto en los campos input específicos */
		input.form-control {
			font-size: 1.5em;  /* Aumenta el tamaño del texto en los inputs */
			height: 3em;       /* Ajusta la altura para que coincida con el tamaño de la fuente */
		}
		/* Aumentar el tamaño del calendario */
		input[type="date"]::-webkit-calendar-picker-indicator {
			width: 60px;  /* Ajusta el ancho */
			height: 60px; /* Ajusta la altura */
			font-size: 4em; /* Cambia el tamaño de la fuente */
		}
		/* Cambiar el tamaño de los números en el calendario */
		.ui-datepicker-calendar td a {
			font-size: 30px;  /* Ajusta el tamaño de los números */
			padding: 10px;    /* Ajusta el espacio alrededor de los números */
		}

		.ui-datepicker {
			font-size: 18px;  /* Ajusta el tamaño de la fuente en el calendario */
		}

		.ui-datepicker-header {
			font-size: 22px;  /* Ajusta el tamaño de la cabecera (mes, año) */
		}		
		
		.form-group {
        margin-bottom: 1rem;
		}

		.input-group {
			border: 1px solid #ced4da;
			border-radius: 8px;
			/*overflow: hidden;*/
			display: flex;
			align-items: center;
			transition: box-shadow 0.3s ease-in-out;
			background: white;
		}

		.input-group:hover {
			box-shadow: 0px 0px 10px rgba(0, 123, 255, 0.3);
		}

		.input-group-text {
			background: #17a2b8;
			border-right: 1px solid #ced4da;
			padding: 10px 15px;
			border-radius: 8px 0 0 8px;
			color: white;
		}

		.input-group-text em {
			font-size: 1.0rem;
		}

		.form-control {
			border-left: 0;
			border-radius: 0 8px 8px 0;
			padding: 12px;
			font-size: 1rem;
		}

		.form-control:focus {
			border-color: #17a2b8;
			outline: none;
			box-shadow: none;
		}    
    </style>
</head>
<body>

    <!-- Sidebar (Menú lateral) -->
    <!-- Sidebar (Menú lateral) -->
	<nav class="sidebar" id="sidebar style=" style="width: 150px;">		
		<ul class="nav flex-column text-center">
			<li class="nav-item">
				<a href="dashboard.php" aria-label="Ir al Dashboard">
					<i class="fa fa-tachometer-alt" aria-hidden="true"></i> Dashboard
				</a>
			</li>
			<li class="nav-item">
				<a href="#" class="nav-link active">
					<i class="fas fa-file-invoice-dollar fa-2x" aria-hidden="true"></i>
					<div class="text-uppercase" style="font-size: 12px;">Ventas</div>
				</a>
			</li>
			<li class="nav-item">
				<a href="historial.php" class="nav-link">
					<i class="fa fa-history fa-2x" aria-hidden="true"></i>
					<div class="text-uppercase" style="font-size: 12px;">Historial</div>
				</a>
			</li>
			<li class="nav-item">
				<a href="javascript:void(0)" class="nav-link" onclick="cerrar();" aria-label="Cerrar sesión">
					<i class="fas fa-sign-out-alt fa-2x" aria-hidden="true"></i>
					<div class="text-uppercase" style="font-size: 12px;">Cerrar Sesión</div>
				</a>
			</li>
		</ul>
	</nav>
	
    <!-- Contenido Principal -->
    <div class="main-content" id="mainContent">
        <nav class="navbar navbar-expand-lg navbar-light bg-light">
            <div class="container-fluid">
                <button class="navbar-toggler" type="button" aria-label="Toggle navigation" onclick="toggleSidebar()">
                    <span class="navbar-toggler-icon"></span>
                </button>
                <a class="navbar-brand" href="#"><i class="fas fa-tachometer-alt"></i> Panel de venta</a>
                <div class="collapse navbar-collapse">
                    <ul class="navbar-nav ms-auto">
                        <li class="nav-item">
                            <a class="nav-link active" href="#"><i class="fa fa-store"></i><?php echo " ".$sucursal; ?></a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link active" href="#"><i class="fa fa-user-secret"></i><?php echo " ".$usuario; ?></a>                        
                        </li>
                        <li class="nav-item">
                            <a class="nav-link"><i class="fa fa-calendar-check"></i> <span id="fechaActual"></span></a>
                        </li>
                        <li class="nav-item d-none d-md-block">
                            <a class="nav-link"><em class="fas fa-clock text-mac"></em>&nbsp;<span id="horaActual"></span></a>
                        </li>
                    </ul>
                </div>
            </div>
        </nav>
		
		<ul class="nav">			
			<li class="nav-item">
				<h5><a class="nav-link active" href="#">Nueva Venta</a></h5>
			</li>
			<li class="nav-item">
				<h5><a class="nav-link" href="pago.php">Aplicar Pago</a></h5>
			</li>			
		</ul>
        <!-- Page content-->
		<div class="content">
			<div class="content-heading">				
				<div class="col-sm-10 col-md-10 col-lg-10 float-left">
					<h3><a>Nueva Venta <i class="fas fa-file-invoice-dollar fa-1x text-primary"></i></a></h3>
				</div>
			</div>
			<!-- Zero Configuration-->
			<!-- START card-->
			<div class="row col-12 col-lg-12">
				<div class="col-4 col-lg-4">					
					<div class="card card-default border-primary mb-3">
						<div class="card-body">
							<!-- Campo de fecha -->
							<form>
								<!--div class="form-group">									
									<div class="input-group with-focus">
										<span class="input-group-text text-muted bg-transparent border-left-0">
											<em class="fas fa-calendar-week fa-3x"></em>
										</span>
										<input id="date" type="date" class="form-control" value="2025-01-27" min="2025-01-27" required>
									</div>
								</div-->
								
								<div class="form-group">
									<div class="input-group with-focus">
										<span class="input-group-text text-muted bg-transparent border-right-0">
											<i class="fas fa-calendar-week fa-2x"></i>
										</span>
										<input id="date" type="date" class="form-control border-left-0" required>
									</div>
								</div>
							
								<!-- Campo de selección de loterías -->
								<div class="col-md-12 form-group">
									<div class="input-group with-focus">
										<span class="input-group-text">
											<em class="fas fa-play fa-3x"></em>
										</span>							
										
										<!--select class="selectpicker form-control input-large" 
												data-live-search="true" required multiple id="loterias" name="loterias">
										</select-->
										<select class="form-control" id="loterias" name="loterias">
										</select>
									</div>
								</div>

								<!-- Campo para ingresar el número -->
								<div class="form-group">
									
									<div class="input-group with-focus">
										<span class="input-group-text text-muted bg-transparent border-left-0">
											<em class="fas fa-list-ol fa-3x"></em>
										</span>
										<input class="form-control border-right-0 numberNoBotones" name="number" id="number" type="number" placeholder=" Ingrese Número" required>
									</div>
								</div>

								<!-- Campo para ingresar el valor -->
								<div class="form-group">									
									<div class="input-group with-focus">
										<span class="input-group-text text-muted bg-transparent border-left-0">
											<em class="fas fa-dollar-sign fa-4x"></em>
										</span>
										<input class="form-control border-right-0 numberNoBotones" name="valor" id="valor" type="number" placeholder="Ingrese Valor" min="0.50" step="0.01" required>
									</div>
								</div>
								<br>
								<!-- Botón de carga -->
								<div class="form-group">
									<div class="input-group with-focus">
										<button  onclick="cargar()" class="btn btn-success btn-lg w-100">Cargar</button>
										
									</div>
								</div>
							</form>
						</div>
					</div>
					<div class="col-12 col-lg-12">
						<div class="card card-default border-info mb-3">
							<div class="card-header bg-info text-center">
								<h2>Números Copados Hoy</h2>
							</div>
							<div class="card-body">
								<table class="table table-responsive table-sm text-center">
									<tbody id="tbCopados">
										<tr><td colspan="3">Cargando números...</td></tr> 
									</tbody>
								</table>
							</div>
						</div>
					</div>
				</div>
				
				<div class="col-4 col-lg-4 table-responsive">
					<!--div class="card card-default border-success mb-3">
						<div class="card-body">
							<form>
								<div class="row">
									<div class="col-auto my-1">
										<div class="custom-control custom-checkbox">
											<input type="checkbox" class="custom-control-input" id="imprimir" checked="false">
											<label class="custom-control-label" for="imprimir">Imprimir</label>
										</div>
									</div>
									<div class="col-auto my-1">
										<div class="custom-control custom-checkbox">
											<input type="checkbox" class="custom-control-input" id="imagen">
											<label class="custom-control-label" for="imagen">Imagen</label>
										</div>
									</div>
								</div>
							</form>
						</div>
					</div-->
					<div class="card card-default border-danger mb-3">
						<div>
							<table id="ticket" class="table table-striped">
								<thead>
									<tr>
										<th>Loteria</th>
										<th>Fecha</th>
										<th>Número</th>
										<th>Valor</th>
										<th>Acción</th>
									</tr>
								</thead>
								<tbody>
									<!-- Los datos se llenarán desde el servidor -->
								</tbody>
								<tfoot>
									<tr>
										<th colspan="3">Total</th>
										<th id="total-value">$0.00</th>
										<th></th>
									</tr>
								</tfoot>
							</table>
						</div>	
						<!-- Botón de carga -->
						<div class="form-group">
							<div class="input-group with-focus">
								<!--button type="submit" onclick="return validarFormulario()" class="btn btn-primary btn-lg w-100" id="save">Aprovar</button-->
								<button onclick="aprovar()" class="btn btn-primary btn-lg w-100" id="save">Aprovar</button>
								
							</div>
						</div>					
					</div>
				</div>
				
				<div class="col-4 col-lg-4">
					<div class="card card-default border-warning mb-3">
						<div class="card-header bg-warning text-center">
							<h2>Últimos Números</h2>
						</div>
						<div class="card-body">
							<table class="table table-responsive table-sm text-center">
								<tbody id="tbUltimas">
									<tr><td colspan="3">Cargando números...</td></tr> 
								</tbody>
							</table>
						</div>
					</div>
				</div>
			</div>			
		</div>
	</div>
   <!-- Bootstrap CSS -->
	<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
	<!-- Bootstrap JS Bundle (incluye Popper.js) -->
	<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
	<!-- Bootstrap-Select CSS -->
	<link href="https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta2/dist/css/bootstrap-select.min.css" rel="stylesheet">
	<!-- Bootstrap-Select JS -->
	<script src="https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta2/dist/js/bootstrap-select.min.js"></script>
	<!-- Localización en español para Bootstrap-Select -->
	<script src="https://cdn.jsdelivr.net/npm/bootstrap-select@1.14.0-beta2/dist/js/i18n/defaults-es_ES.min.js"></script>
	<!-- Summernote CSS -->
	<link href="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-lite.min.css" rel="stylesheet">
	<!-- Summernote JS -->
	<script src="https://cdn.jsdelivr.net/npm/summernote@0.8.18/dist/summernote-lite.min.js"></script>
	<!-- Asegúrate de que los scripts necesarios estén cargados -->
	<script src="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/js/all.min.js"></script>
	<script src="../../resources/media/js/jquery.dataTables.min.js"></script>
	<script src="../../resources/media/js/dataTables.bootstrap.min.js"></script>
	<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
	<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>

	<script src="../../resources/js/menu_ticket.js"></script>
	<!--script src="https://code.jquery.com/jquery-3.6.0.min.js"></script-->
	<script>
		$(document).ready(function () 
		{
			function cargarNumeros() 
			{
				$.ajax
				({
					url: 'obtener_numeros.php',
					type: 'GET',
					dataType: 'json',
					success: function (data) 
					{
						let contenido = "";
						if (data.length > 0) 
						{
							data.forEach((num, index) => 
							{
								// Formatear el número para que tenga siempre 3 dígitos
								const numeroFormateado = num.numero.padStart(3, '0');
								if (index % 3 === 0) contenido += "<tr>"; // Nueva fila cada 3 números
								contenido += `
									<td>
										<div class="form-group">
											<small class="form-text text-muted" style="font-size:15px">${num.loteria}</small><br> <!-- Aquí se utiliza el loteria desde el JSON -->                                
											<button class="btn btn-dark" style="font-size:36px; margin: 5px">${numeroFormateado}</button><br>                                   
											<small class="form-text text-muted" style="font-size:20">${num.valor}</small> <!-- Aquí se utiliza el valor desde el JSON -->
										</div>
									</td>`;
								if (index % 3 === 2) contenido += "</tr>"; // Cerrar fila cada 3 números
							});
							if (data.length % 3 !== 0) contenido += "</tr>"; // Cerrar la última fila si es necesario
						} 
						else 
						{
							contenido = "<tr><td colspan='3'>No hay números comprados hoy</td></tr>";
						}
						$("#tbUltimas").html(contenido);
					},
					error: function (xhr, status, error) 
					{
						console.error("Error: " + error); // Log del error en la consola
						$("#tbUltimas").html("<tr><td colspan='3'>Error al cargar los datos</td></tr>");
					}
				});
			}
			cargarNumeros(); // Cargar al inicio
			// Refrescar los números cada 30 segundos
			setInterval(cargarNumeros, 30000);
		});
	
		
		$(document).ready(function () {
			function cargarCopados() {
				$.ajax({
					url: 'obtener_copados.php',
					type: 'GET',
					dataType: 'json',
					success: function (data) {
						let contenido = "";

						// Verifica si hay datos
						if (data.numeros_superan_cupo.length > 0) {
							data.numeros_superan_cupo.forEach((num, index) => {
								const numeroFormateado = num.numero.padStart(3, '0'); // Formatear a 3 dígitos
								const valor = num.total; // Obtener valor para mostrar

								if (index % 3 === 0) contenido += "<tr>"; // Nueva fila cada 3 números
								contenido += `
									<td>
										<div class="form-group">
											<button class="btn btn-dark" style="font-size:36px; margin: 5px">${numeroFormateado}</button><br>                                   
											<small class="form-text text-muted" style="font-size:20px">T2</small> <!-- Mostrar el valor -->
										</div>
									</td>`;
								if (index % 3 === 2) contenido += "</tr>"; // Cerrar fila cada 3 números
							});
							if (data.numeros_superan_cupo.length % 3 !== 0) contenido += "</tr>"; // Cerrar la última fila si es necesario
						} else {
							contenido = "<tr><td colspan='3'>No hay números comprados hoy</td></tr>";
						}

						$("#tbCopados").html(contenido);
					},
					error: function (xhr, status, error) {
						console.error("Error: " + error); // Log del error en la consola
						$("#tbCopados").html("<tr><td colspan='3'>Error al cargar los datos</td></tr>");
					}
				});
			}

			cargarCopados(); // Cargar al inicio
			// Refrescar los números cada 30 segundos
			setInterval(cargarCopados, 30000);
		});


		function cerrar() 
		{
			Swal.fire({
			title: '¿Estás seguro?',
			text: '¿Deseas cerrar sesión?',
			icon: 'warning',
			showCancelButton: true,
			confirmButtonText: 'Sí, cerrar sesión',
			cancelButtonText: 'Cancelar',
			customClass: 
			{
				confirmButton: 'swal2-confirm',
				cancelButton: 'swal2-cancel',
			}
			}).then((result) => 
			{
				if (result.isConfirmed) 
				{
					// Mostrar loader
					const loader = document.createElement('div');
					loader.className = 'loader';
					loader.textContent = 'Cerrando sesión...';
					document.body.appendChild(loader);

					// Enviar solicitud
					fetch('../../controllers/usuario.php',{
						method: 'POST',
						headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
						body: new URLSearchParams({ boton: 'cerrar' }),})
					.then((response) => 
					{
						if (!response.ok) 
						{
							throw new Error('Error en la solicitud: ' + response.statusText);
						}
						return response.text();
					})
					.then(() =>{
						location.href = '../index.php';
					})
					.catch((error) => {
						Swal.fire('Error', 'Hubo un error al cerrar sesión: ' + error.message, 'error');
					})
					.finally(() => {
						loader.remove();
					});
				}
			});
		}
		
		/*document.addEventListener("DOMContentLoaded", function() {
			let today = new Date().toISOString().split('T')[0]; // Obtener la fecha actual en formato YYYY-MM-DD
			let dateInput = document.getElementById("date");
			dateInput.min = today; // Establecer la fecha mínima
			dateInput.value = today; // Establecer la fecha seleccionada por defecto
		});*/
		
		//funcion del calendario con la region de ecuador 
		document.addEventListener("DOMContentLoaded", function() {
			let now = new Date(); // Fecha actual en UTC
			let ecuadorTime = new Date(now.toLocaleString("en-US", { timeZone: "America/Guayaquil" }));
			
			let year = ecuadorTime.getFullYear();
			let month = String(ecuadorTime.getMonth() + 1).padStart(2, "0");
			let day = String(ecuadorTime.getDate()).padStart(2, "0");
			
			let formattedDate = `${year}-${month}-${day}`; // Formato YYYY-MM-DD
			
			let dateInput = document.getElementById("date");
			if (dateInput) {
				dateInput.min = formattedDate; // Establecer fecha mínima
				dateInput.value = formattedDate; // Establecer fecha predeterminada
			}
		});

		
		
        function toggleSidebar() 
		{
            document.getElementById('sidebar').classList.toggle('show');
        }

        // Mostrar la fecha y hora actual
        $(document).ready(function () {
            dayjs.locale('es');
            $('#fechaActual').text(dayjs().format('dddd, DD MMMM YYYY'));
            setInterval(function () {
                $('#horaActual').text(dayjs().format('h:mm A'));
            }, 60000);

            // Resaltar el enlace activo
            $('.sidebar a').each(function () {
                if (this.href === window.location.href) {
                    $(this).addClass('active');
                }
            });
        });		
		

		
		/*//Funcion loterias una sola seleccion
		$(document).ready(function() {
			
			var date = $('#date').val();
			if (fecha !== ) 
			{
				var parameter = 
				{
					"fecha": fecha,					
				};
				$.ajax({
					type: "POST",
					url: "datos.php?Accion=GetLoterias",
					
					success: function(response)
					{
						$('#loterias').html(response).fadeIn();
					}
				});
			}
		});*/
		
		$(document).ready(function() {
			$('#date').change(function() { // Ejecutar solo cuando cambie la fecha
				var date = $(this).val(); // Obtener el valor del input

				if (date !== "") { // Verificar si la fecha no está vacía
					$.ajax({
						type: "POST",
						url: "datos.php?Accion=GetLoterias",
						data: { "fecha": date }, // Coincidir con el nombre en PHP
						success: function(response) {
							$('#loterias').html(response).fadeIn();
						},
						error: function(xhr, status, error) {
							console.error("Error en la solicitud AJAX:", error);
						}
					});
				}
			});
		});
		
		$(document).ready(function() {			
			//var date = $(this).val(); // Obtener el valor del input
			//var date = '2025-03-05';
			let date = $('#date').val(); 
			if (date !== "") { // Verificar si la fecha no está vacía
				$.ajax({
					type: "POST",
					url: "datos.php?Accion=GetLoterias",
					data: { "fecha": date }, // Coincidir con el nombre en PHP
					success: function(response) {
						$('#loterias').html(response).fadeIn();
					},
					error: function(xhr, status, error) {
						console.error("Error en la solicitud AJAX:", error);
					}
				});
			}			
		});

		
		//Funcion loterias multi seleccion
		/*$(document).ready(function() {
			$.ajax({
				type: "POST",
				url: "datos.php?Accion=GetLoterias",
				success: function(response) {
					$('#loterias').html(response).fadeIn();
					// Refrescar selectpicker después de actualizar opciones
					$('#loterias').selectpicker('refresh');
				}
			});
		});*/
		
		//guardar ticket
		function cargar() {
			var date = $('#date').val();
			var loterias = $('#loterias').val();
			var number = parseInt($('#number').val(), 10); // Convertir a entero
			var valor = parseFloat($('#valor').val()); // Convertir a número decimal
			//alert (valor);
			if (date !== "" && loterias !== "") 
			{
				if(number >= 0 && number <= 999)
				{
					if(valor >= 0.50 && valor <= 20)
					{
						$.ajax({
							url: 'guardar_ticket.php',
							type: 'POST',
							data: {
								date: encodeURIComponent(date),
								loterias: encodeURIComponent(loterias),
								number: number,
								valor: valor
							}
						}).done(function(respuesta) {
							//alert (respuesta);
							if (respuesta.trim() === "") {
								$('#ticket').DataTable().ajax.reload();
							} else {
								Swal.fire('Error', "Los datos no fueron ingresados correctamente", 'error');
							}
						}).fail(function() {
							Swal.fire('Error', "Error en la comunicación con el servidor", 'error');
						});
					}
					else
					{
						Swal.fire('Error', 'El valor ingresado esta fuera del rango estre 0.50 y 40.', 'error');
					}
				}
				else
				{
					Swal.fire('Error', 'El número ingresado esta fuera del rango estre 0 y 999.', 'error');
				}
			} 
			else 
			{
				Swal.fire('Error', 'Hay campos sin llenar o con valores incorrectos.', 'error');
			}
			
		}

		function aprovar() 
		{
			
			window.location.href = 'qr/index.php'; // Redirige a la nueva ruta
				
		}
		//Aprovar e imprimir ticket
		/*function aprovar() 
		{
			Swal.fire({
				title: 'Aprovación', // Título corregido				
				icon: 'info',
				showCancelButton: true, // Muestra el botón de cancelar
				confirmButtonText: 'Aceptar e Imprimir',
				cancelButtonText: 'Cancelar'
			}).then((result) => {
				if (result.isConfirmed) {
					window.location.href = 'qr/index.php'; // Redirige a la nueva ruta
				}
				// Si el usuario hace clic en "Cancelar", no se hace nada
			});
		}*/

    </script>
</body>
</html>
